<?php
/**
* @file likno_accordions.admin.inc
* Functions that are only called on the admin pages.
*/

/*This function is used by file_Save_upload to validate the filename of the uploaded file
*/
function likno_accordions_validate_filename($file, $filename) {
	$errors = array();
	// Bypass validation for uid  = 1.
	
	if ($file->filename != "drupal_".$filename.".zip") {
		$errors[] = t('Filename must be : %filename.', array('%filename' => "drupal_".$filename.".zip"));
	}
	return $errors;
}

function likno_accordions_accordion_operations() {
	$operations = array(
		'active' => array(
			'label' => t('Activated selected accordions'),
			'callback' => 'likno_accordions_mass_update',
			'callback arguments' => array('updates' => array('active' => TRUE))
		),
		'deactivate' => array(
			'label' => t('Deactivate selected content'),
			'callback' => 'likno_accordions_mass_update',
			'callback arguments' => array('updates' => array('active' => FALSE))
		),
		'delete' => array(
			'label' => t('Delete selected accordions'),
			'callback' => NULL
		)
	);
	return $operations;
}

function likno_accordions_mass_update($accordions, $updates) {
	// We use batch processing to prevent timeout when updating a large number
	// of nodes.
	if (count($accordions) > 10) {
		$batch = array(
			'operations' => array(
				array('_likno_accordions_mass_update_batch_process', array($accordions, $updates))
			),
			'finished' => '_likno_accordions_update_batch_finished',
			'title' => t('Processing'),
			// We use a single multi-pass operation, so the default
			// 'Remaining x of y operations' message will be confusing here.
			'progress_message' => '',
			'error_message' => t('The update has encountered an error.'),
			// The operations do not live in the .module file, so we need to
			// tell the batch engine which file to load before calling them.
			'file' => drupal_get_path('module', 'likno_accordions') . '/likno_accordions.admin.inc'
		);
		batch_set($batch);
	} else {
		foreach ($accordions as $id) {
			_likno_accordions_mass_update_helper($id, $updates);
		}
		drupal_set_message(t('The update has been performed.'));
	}
}

function _likno_accordions_mass_update_helper($id, $updates) {
	$accordion = accordion_load($id);
	
	foreach ($updates as $name => $value) {
		$accordion->$name = $value;
	}
	accordion_save($accordion);
	return $accordion;
}

/* This function unzips a file
* name: the name of the file to unzip
* folder: the target location of the unzipped files
*/
function likno_accordions_unzipper($name, $folder){
	if (class_exists('ZipArchive')) {
		$zip = new ZipArchive;
		$res = $zip->open($name);
		if ($res === TRUE) {
			if ($zip->extractTo($folder)){
				$zip->close();
				return 1;
			} else return 0;
		} else return 0;
	}
	return 0;
}

function likno_accordions_accordion_edit($accordion) {
	drupal_set_title(t('<em>Edit accordion</em> @title', array( '@title' => $accordion->name)), PASS_THROUGH);
	return drupal_get_form('likno_accordions_accordion_form', $accordion);
}

function likno_accordions_add() {
	return drupal_get_form('likno_accordions_accordion_form',null);
	//return theme('node_add_list', array('content' => $content));
}


function likno_accordions_accordion_form($form, &$form_state, $accordion) {
	global $user;
	global $base_url;
	drupal_add_js(drupal_get_path('module', 'likno_accordions') . '/likno_accordions.js');
	drupal_add_js("ZeroClipboard.setMoviePath( '".$base_url."/".drupal_get_path('module', 'likno_accordions')."/clipboard.swf' );",'inline');
	drupal_add_css('.form-item-position{padding-bottom: 0px!important;margin-bottom: 0px!important;}#lwac_divname,#lwac_shortcode{padding: 2px;margin-top: 10px;width: 200px;background-color:#D2D2D2;}#lwac_shortcode{margin-top: 10px;}#lwac_copy_button.active,#lwac_shortcode_button.active{text-decoration: none; background-color:#5a5a5a; background-image:none; color:#D2D2D2;}','inline');
	// During initial form build, add the node entity to the form state for use
	// during form building and processing. During a rebuild, use what is in the
	// form state.
	$i = 1;
	if ($accordion == null){
		$accordion = new stdClass();
		while (true){
			$result = db_query("SELECT name FROM {lwac_table} WHERE name = :name", array(
				':name' => "accordion".$i
			));
			$name = $result->fetchField();
			if ($name!=null){
				if ($name!="accordion".$i) break;
				else $i++;
			} else break;
		}
		$accordion->name = "accordion".$i;
		$accordion->active = 0;
		$accordion->position = "shortcode";
		$accordion->print_div = 1;
		$accordion->acc_struct = "";
	}
	
	if (!isset($form_state['accordion'])) {
		if (!isset($accordion->name)) {
			$accordion->name = NULL;
		}
		$form_state['accordion'] = $accordion;
	} else {
		$accordion = $form_state['accordion'];
	}
	
	// Basic node information.
	// These elements are just values so they are not even sent to the client.
	foreach (array('id') as $key) {
		$form[$key] = array(
			'#type' => 'value',
			'#value' => isset($accordion->$key) ? $accordion->$key : NULL
		);
	}
	// Changed must be sent to the client, for later overwrite error checking.
	// If the node type has a title, and the node type form defined no special
	// weight for it, we default to a weight of -5 for consistency.
	if (isset($form['title']) && !isset($form['title']['#weight'])) {
		$form['title']['#weight'] = -5;
	}
	
	$form['additional_settings'] = array(
		'#type' => 'vertical_tabs',
		'#weight' => 99
	);
	
	$form['upload'] = array(
		'#type' => 'file',
		'#title' => t('Upload accordion files'),
		'#size' => '100%'
	);
	
	$form['name'] = array(
		'#type' => 'textfield',
		'#title' => t('Accordion name'),
		'#default_value' => $accordion->name,
		'#size' => 60,
		'#maxlength' => 128,
		'#description' => t('Please make sure that the "Accordion name" value matches
		the value in the "Compiled Javascript Project" property of the Likno Web Accordion Builder project file
		(Tools > Project Properties > Folders). <a href="#" id="lwac_show_me_toggle">show me</a>'.
		'<div style="text-align: center; max-width: 800px; margin-top: 20px; display: none; background-color: #FEFCF5; border: #E6DB55 solid 1px; padding: 10px 0;" id="lwac_show_this">'.
		'		<strong>More info</strong> - <a href="#" class="lwac_show_me_close">close</a>
		<br />
		<br />
		<img src="'.$base_url.'/'.drupal_get_path('module', 'likno_accordions').'/accordionname.jpg" alt="Project Name" title="Project Name"/>
		<br />
		<br />
		Compiled Javascript Project(see <span style="color: red;">1</span>) and accordion name (see <span style="color: red;">2</span>) must be the same
		<br />
		<br />
		<img src="'.$base_url.'/'.drupal_get_path('module', 'likno_accordions').'/accordionnamesec.jpg" alt="Accordion Name" title="Accordion Name"/>
		<br />
		<br />
		<a href="#" class="lwac_show_me_close">close</a>
		</div>')
	);
	$lwac_indic_text = ($accordion->active == 1)? "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;This accordion will appear in your site" : "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;This accordion will NOT appear in your site";
	$lwac_indic_color = ($accordion->active == 1)? "green" : "red";
	
	$form['active'] = array(
		'#type' => 'checkbox',
		'#title' => 'Show (enabled) <i>'.
			$accordion->name .
			'</i> in site <span id="lwac_indic_text">'.$lwac_indic_text.'</span>',
		'#default_value' =>  0, //by default show the 1st menu? (YES)
		'#return_value' => 1
	);

	if ($accordion->active == 1 )
	$form['active']['#attributes']['checked'] = true;
	
	$form['print_div'] = array(
		'#type' => 'checkbox',
		'#title' => t("Print 'DIV' element")
	);
	if ($accordion->print_div == 1) $form['print_div']['#attributes']['checked'] = true;
	$form['printed_div'] = array(
		'#type' => 'item',
		'#title' => "A 'DIV' element will be produced with this id:",
		'#markup' => t('<input readonly type="text" id="lwac_divname" value="lwacAnchor-'.$accordion->name.'"/>
			<a class="button" id="lwac_copy_button">Copy</a>'),
		'#states' => array(
			// Hide the settings when the cancel notify checkbox is disabled.
			'invisible' => array(
				'input[name="print_div"]' => array('checked' =>FALSE)
			)
		)
	);
	
	$form['position-container'] = array(
		'#type' => 'container'
	);
	$form['position-container']['position'] = array(
		'#type' => 'radios',
		'#title' => t('Please select positioning method of the accordion'),
		'#options' => array('shortcode' => t('Shortcode'),'block' => t('Block')),
		'#default_value' =>  $accordion->position
	);
	
	$form['position-container']['shortcode-notice'] = array(
		'#type' => 'item',
		'#title' => 'Shortcode',
		'#markup' => 'The accordion will be placed inside a page/article. <br />
			Use this shortcode to place it: 
			<input readonly type="text" id="lwac_shortcode" value="[accordion:'.$accordion->name.']"/>
			<a class="button" id="lwac_shortcode_button">Copy</a>',
		// Hide the settings when the cancel notify checkbox is disabled.
		'#states' => array(
			'invisible' => array(
				'input[name="position"]' => array('value' => "block")
			)
		)
	);
	
	$form['position-container']['block-notice'] = array(
		'#type' => 'item',
		'#title' => 'Block',
		'#markup' => 'The accordion will be placed as a block. Go to '.l('admin/structure/block', 'admin/structure/block') .' and you will find a block with the name of this accordion.' ,
		'#states' => array(
			// Hide the settings when the cancel notify checkbox is disabled.
			'invisible' => array(
				'input[name="position"]' => array('value' => "shortcode")
			)
		)
	);
	
	if (!isset($accordion->acc_struct)) {
		$accordion->acc_struct = "";
	}
	
	
	$form['structure'] = array(
		'#type' => 'hidden',
		'#value' => $accordion->acc_struct
	);
	$form['actions'] = array('#type' => 'actions');
	$form['actions']['submit'] = array(
		'#type' => 'submit',
		'#access' => user_access('administer likno_accordions'),
		'#value' => t('Save'),
		'#weight' => 5,
		'#submit' => array('likno_accordions_form_submit')
	);
	if (!empty($accordion->id)) {
		$form['actions']['delete'] = array(
			'#type' => 'submit',
			'#value' => t('Delete'),
			'#weight' => 15,
			'#submit' => array('likno_accordions_form_delete_submit')
		);
	}
	$form['actions']['back'] = array(
		'#type' => 'link',
		'#title' => 'Back to admin page',
		'#weight' => 25,
		'#href' => 'admin/settings/likno_accordions'
	);
	
	// This form uses a button-level #submit handler for the form's main submit
	// action. node_form_submit() manually invokes all form-level #submit handlers
	// of the form. Without explicitly setting #submit, Form API would auto-detect
	// node_form_submit() as submit handler, but that is the button-level #submit
	// handler for the 'Save' action. To maintain backwards compatibility, a
	// #submit handler is auto-suggested for custom node type modules.
	$form['#validate'][] = 'likno_accordions_form_validate';
	if (!isset($form['#submit']) && function_exists('likno_accordions_form_submit')) {
		$form['#submit'][] = 'likno_accordions_form_submit';
	}
	$form += array('#submit' => array());
	
	//field_attach_form('node', $node, $form, $form_state, $node->language);
	return $form;
}




/**
* Module settings form.
* callback function for likno_accordions_menu() in likno_accordions.module
*/
function likno_accordions_settings($form, $form_state) {
	if (isset($form_state['values']['operation']) && $form_state['values']['operation'] == 'delete') {
		return likno_accordions_multiple_delete_confirm($form, $form_state, array_filter($form_state['values']['accordions']));
	}
	//$form['filter'] = node_filter_form();
	//$form['#submit'][] = 'node_filter_form_submit';
	$form['admin'] = likno_accordions_admin_accordions();
	return $form;
}

function likno_accordions_multiple_delete_confirm($form, &$form_state, $accordions){
	$form['accordions'] = array('#prefix' => '<ul>', '#suffix' => '</ul>', '#tree' => TRUE);
	// array_filter returns only elements with TRUE values
	foreach ($accordions as $id => $value) {
		$name = db_query('SELECT name FROM {lwac_table} WHERE id = :id', array(':id' => $id))->fetchField();
		$form['accordions'][$id] = array(
			'#type' => 'hidden',
			'#value' => $id,
			'#prefix' => '<li>',
			'#suffix' => check_plain($name) . "</li>\n"
		);
	}
	$form['operation'] = array('#type' => 'hidden', '#value' => 'delete');
	$form['#submit'][] = 'likno_accordions_multiple_delete_confirm_submit';
	$confirm_question = format_plural(count($accordions),
		'Are you sure you want to delete this item?',
		'Are you sure you want to delete these items?');
	return confirm_form($form,
		$confirm_question,
		'admin/settings/likno_accordions', t('This action cannot be undone.'),
		t('Delete'), t('Cancel'));
}

function likno_accordions_multiple_delete_confirm_submit($form, &$form_state) {
	if ($form_state['values']['confirm']) {
		likno_accordions_delete(array_keys($form_state['values']['accordions']));
		$count = count($form_state['values']['accordions']);
		watchdog('content', 'Deleted @count accordions.', array('@count' => $count));
		drupal_set_message(format_plural($count, 'Deleted 1 accordion.', 'Deleted @count accordions.'));
	}
	$form_state['redirect'] = 'admin/settings/likno_accordions';
}


function likno_accordions_settings_submit($form, &$form_state){
	$path = $form_state['values']['lwac_path'];
	if ($path[0] != "/") $path = "/".$path;
	if ($path[strlen($path)-1] != "/") $path = $path."/";
	variable_set('lwac_path',$path );
}


/**
* Validate node_admin_nodes form submissions.
*
* Check if any nodes have been selected to perform the chosen
* 'Update option' on.
*/
function likno_accordions_admin_accordions_validate($form, &$form_state) {
	// Error if there are no items to select.
	if (!is_array($form_state['values']['accordions']) || !count(array_filter($form_state['values']['accordions']))) {
		form_set_error('', t('No items selected.'));
	}
}

/**
* Process node_admin_nodes form submissions.
*
* Execute the chosen 'Update option' on the selected nodes.
*/
function likno_accordions_admin_accordions_submit($form, &$form_state) {
	$operations = module_invoke_all('accordion_operations');
	$operation = $operations[$form_state['values']['operation']];
	// Filter out unchecked nodes
	$accordions = array_filter($form_state['values']['accordions']);
	if ($function = $operation['callback']) {
		// Add in callback arguments if present.
		if (isset($operation['callback arguments'])) {
			$args = array_merge(array($accordions), $operation['callback arguments']);
		} else {
			$args = array($accordions);
		}
		call_user_func_array($function, $args);
		cache_clear_all();
	} else {
		// We need to rebuild the form to go to a second step. For example, to
		// show the confirmation form for the deletion of nodes.
		$form_state['rebuild'] = TRUE;
	}
}


/**
* Form builder: Builds the node administration overview.
*/
function likno_accordions_admin_accordions() {
	global $base_url;
	$admin_access = user_access('administer likno_accordions');
	$form = array();
	// Build the 'Update notice'
	if (variable_get('LWAC_Check_Show',TRUE)) {
		$LWAC_buildText = LWAC_check();
		if ( $LWAC_buildText != '' ) {
			$form['update-area'] = array(
				'#type'=>'fieldset',
				'#title' => 'Update Notificiations'
			);
			$form['update-area']['update-notice'] = array(
				'#type'=>'item',
				'#prefix'=>'<div style="max-width: 800px; margin-top: 20px; margin-bottom: 15px; background-color: #FEFCF5; border: #E6DB55 solid 1px; padding: 10px 0;">',
				'#suffix'=>'</div>',
				'#markup'=>$LWAC_buildText);
			$form['update-area']['hide-not-submit'] = array(
				'#type' => 'submit',
				'#value' => t('Hide Notifications'),
				'#submit' => array('likno_accordions_system_hide_notifications'));
		} else variable_set('LWAC_Check_Show', FALSE);
	}
	
	// Build the 'settings' form;
	$form['settings'] = array(
		'#type' => 'fieldset',
		'#title' => t('Settings'),
		'#attributes' => array('class' => array('container-inline')),
		'#access' => $admin_access
	);
	
	// LWAC online folder
	$form['settings']['lwac_path'] = array(
		'#type' => 'textarea',
		'#title' => t('Online folder for accordion files'),
		'#default_value' =>  variable_get('lwac_path', "/". drupal_get_path('module', 'likno_accordions')."/files/"),
		'#cols' => 10,
		'#rows' => 1,
		'#description' => t('Every time you compile your Likno Web Accordion Builder project you should also upload the produced ZIP file online (see above). Its content (accordion files) are then automatically added by the plugin to this folder '.
			$base_url.'<span id="lwac_the_path">'. variable_get('lwac_path', "/".drupal_get_path('module', 'likno_accordions')."/files/") .'</span>'.
			'<br>(note: you might need to create this online folder yourself)')
	);
	
	$form['settings']['submit'] = array(
		'#type' => 'submit',
		'#value' => t('Save'),
		'#submit' => array('likno_accordions_settings_submit')
	);
	// Build the 'Update options' form.
	$form['options'] = array(
		'#type' => 'fieldset',
		'#title' => t('Update options'),
		'#attributes' => array('class' => array('container-inline')),
		'#access' => $admin_access
	);
	$options = array();
	foreach (module_invoke_all('accordion_operations') as $operation => $array) {
		$options[$operation] = $array['label'];
	}
	$form['options']['operation'] = array(
		'#type' => 'select',
		'#title' => t('Operation'),
		'#title_display' => 'invisible',
		'#options' => $options,
		'#default_value' => 'approve'
	);
	$form['options']['submit'] = array(
		'#type' => 'submit',
		'#value' => t('Update'),
		'#validate' => array('likno_accordions_admin_accordions_validate'),
		'#submit' => array('likno_accordions_admin_accordions_submit')
	);
	
	// Build the sortable table header.
	$header = array(
		'name' => array('data' => t('Name'), 'field' => 'a.name'),
		'position' => array('data' => t('Position'), 'field' => 'a.position'),
		'active' => array('data' => t('Active'), 'field' => 'a.active')
	);
	$header['operations'] = array('data' => t('Operations'));
	
	$query = db_select('lwac_table', 'a')->extend('PagerDefault')->extend('TableSort');
	//node_build_filter_query($query);
	
	try {
		$accordions = $query
			->fields('a',array('acc_struct'))
			->execute();
	} catch (Exception $e) {
		$spec = array(
			'type' => 'text',
			'description' => 'The struture code of this accordion, always treated as full HTML.'
		);
		db_add_field('lwac_table', 'acc_struct', $spec);
	}
	$accordions = $query
		->fields('a',array('id','name','position','active','acc_struct'))
		->limit(50)
		->orderByHeader($header)
		->execute();
	
	$destination = drupal_get_destination();
	$options = array();
	foreach ($accordions as $accordion) {
		$options[$accordion->id] = array(
			'name' => array(
				'data' => array( 
					'#type' => 'link',
					'#title' => $accordion->name,
					'#href' => 'admin/settings/likno_accordions/' . $accordion->id . '/edit'
					#query' => $destination
				),
			),
			'position' => $accordion->position,
			'active' => ($accordion->active)?"<span style='color: green'>YES</span>":"<span style='color: red'>NO</span>"
		);
		// Build a list of all the accessible operations for the current node.
		$operations = array();
		
		$operations['edit'] = array(
			'title' => t('edit'),
			'href' => 'admin/settings/likno_accordions/' . $accordion->id . '/edit'
			//'query' => $destination,
		);
		
		$operations['delete'] = array(
			'title' => t('delete'),
			'href' => 'admin/settings/likno_accordions/' . $accordion->id . '/delete',
			'query' => $destination
		);
		
		$options[$accordion->id]['operations'] = array();
		if (count($operations) > 1) {
			// Render an unordered list of operations links.
			$options[$accordion->id]['operations'] = array(
				'data' => array(
					'#theme' => 'links__node_operations',
					'#links' => $operations,
					'#attributes' => array('class' => array('links', 'inline'))
				)
			);
		} elseif (!empty($operations)) {
			// Render the first and only operation as a link.
			$link = reset($operations);
			$options[$accordion->id]['operations'] = array(
				'data' => array(
					'#type' => 'link',
					'#title' => $link['title'],
					'#href' => $link['href'],
					'#options' => array('query' => $link['query'])
				)
			);
		}
	}
	
	// Only use a tableselect when the current user is able to perform any
	// operations.
	if ($admin_access) {
		$form['accordions'] = array(
			'#type' => 'tableselect',
			'#header' => $header,
			'#options' => $options,
			'#empty' => t('No content available.')
		);
	}
	// Otherwise, use a simple table.
	
	$form['pager'] = array('#markup' => theme('pager'));
	return $form;
}

function likno_accordions_form_validate($form, &$form_state) {
	// $form_state['node'] contains the actual entity being edited, but we must
	// not update it with form values that have not yet been validated, so we
	// create a pseudo-entity to use during validation.
	$accordion = (object) $form_state['values'];
	if (empty($accordion->name)) {
		// The use of empty() is mandatory in the context of usernames
		// as the empty string denotes the anonymous user. In case we
		// are dealing with an anonymous user we set the user ID to 0.
		form_set_error('name', 'Name cannot be empty');
	}
	else if ((isset($accordion->id) && db_query("SELECT name FROM {lwac_table} WHERE name = :name and id !=:id", array(  ':name' => $accordion->name, ':id'=>$accordion->id))->rowCount()>0) || (!isset($accordion->id) && db_query("SELECT name FROM {lwac_table} WHERE name = :name ", array(  ':name' => $accordion->name))->rowCount()>0)){
		form_set_error('name', t('There is another accordion with name: %name.', array('%name' => $accordion->name)));
	}
}
function likno_accordions_form_delete_submit($form, &$form_state){
	$destination = array();
	if (isset($_GET['destination'])) {
		$destination = drupal_get_destination();
		unset($_GET['destination']);
	}
	$accordion = (object) $form_state['values'];
	$form_state['redirect'] = array('admin/settings/likno_accordions/'.$accordion->id.'/delete', array('query' => $destination));


}

/**
* Delete multiple accordions.
*
* @param $ids
*   An array of node IDs.
*/
function likno_accordions_delete($ids) {
	$transaction = db_transaction();
	if (!empty($ids)) {
	try {
		// Delete after calling hooks so that they can query node tables as needed.
			db_delete('lwac_table')
			->condition('id', $ids, 'IN')
			->execute();
		}
		catch (Exception $e) {
			$transaction->rollback();
			watchdog_exception('node', $e);
			throw $e;
		}
	}
}


/**
* Menu callback -- ask for confirmation of node deletion
*/
function likno_accordions_delete_confirm($form, &$form_state, $accordion) {
	$form['#accordion'] = $accordion;
	// Always provide entity id in the same form key as in the entity edit form.
	$form['id'] = array('#type' => 'value', '#value' => $accordion->id);
	return confirm_form($form,
		t('Are you sure you want to delete %name?', array('%name' => $accordion->name)),
		'admin/settings/likno_accordions/' . $accordion->id."/edit",
		t('This action cannot be undone.'),
		t('Delete'),
		t('Cancel')
	);
}

/**
* Execute node deletion
*/
function likno_accordions_delete_confirm_submit($form, &$form_state) {
	if ($form_state['values']['confirm']) {
		$accordion = accordion_load($form_state['values']['id']);
		likno_accordions_delete(array($form_state['values']['id']));
		drupal_set_message(t('Accordion %name has been deleted.', array( '%name' => $accordion->name)));
	}
	$form_state['redirect'] = 'admin/settings/likno_accordions';
}


function likno_accordions_form_submit($form, &$form_state) {
	$path = ".".variable_get('lwac_path', "/". drupal_get_path('module', 'likno_accordions')."/files/");
	$accordion = new stdClass();
	$accordion->id = $form_state['values']['id'];
	$accordion->name = $form_state['values']['name'];
	$accordion->active = $form_state['values']['active'];
	$accordion->print_div = $form_state['values']['print_div'];
	$accordion->position = $form_state['values']['position'];
	$accordion->acc_struct = $form_state['values']['structure'];
	
	$insert = empty($accordion->id);
	accordion_save($accordion);
	drupal_theme_rebuild();
	if ($insert) {
		drupal_set_message(t('Accordion '.$accordion->name.' has been created.'));
	} else {
		drupal_set_message(t('Accordion '.$accordion->name.' has been updated.'));
	}
	
	if ($accordion->id) {
		$form_state['values']['id'] = $accordion->id;
		$form_state['id'] = $accordion->id;
		$form_state['redirect'] = 'admin/settings/likno_accordions';
		
		if (file_exists($path.$accordion->name."/".$accordion->name.'_struct.txt')) {
			unlink($path.$accordion->name."/".$accordion->name.'_struct.txt');
		}
		
		if ($_FILES['files']['size']['upload']) {
			$limits = array ( 'extensions' => "zip", 'filename' => $accordion->name ) ;
			$validators = array('file_validate_extensions' => array($limits['extensions']),'likno_accordions_validate_filename' => array($limits['filename'] ) );
			$file = file_save_upload('upload', $validators, false,FILE_EXISTS_REPLACE);
		} else {
			cache_clear_all();
			return;
		}
		if (isset($file) && $file == false ){
			$errors = form_get_errors();
			drupal_set_message(t('Error uploading file'),'error' );
			$form_state['rebuild'] = TRUE;
			cache_clear_all();
			return;
		} else {

		}
		
		if (file_prepare_directory($path, FILE_MODIFY_PERMISSIONS | FILE_CREATE_DIRECTORY)){
			if (!likno_accordions_unzipper(drupal_realpath($file->destination),$path)){
				drupal_set_message(t("Error unzipping file."),'error');
				$form_state['rebuild'] = TRUE;
				cache_clear_all();
				return;
			} else {
			}
		} else {
			drupal_set_message(t("Check if folder ".$path." exists and if it is writable"),'error');
			$form_state['rebuild'] = TRUE;
			cache_clear_all();
			return;
		}
		
		$struct = "";
		if (substr($path, -1)!="/") $path .= "/";
		if (file_exists($path.$accordion->name."/".$accordion->name.'_struct.txt')) {
			if ($acc_struct_file = fopen($path.$accordion->name."/".$accordion->name.'_struct.txt', 'r')) {
				while ($tmp=fgets($acc_struct_file)) {
					$struct .= $tmp;
				}
			}
		} else {
			// no struct file
		}
		$accordion->acc_struct = $struct;
		db_update("lwac_table")
			->fields(array('acc_struct'=>$accordion->acc_struct))
			->condition('id',$accordion->id,'=')
			->execute();
	} else {
		// In the unlikely case something went wrong on save, the node will be
		// rebuilt and node form redisplayed the same way as in preview.
		drupal_set_message(t('The accordion could not be saved.'), 'error');
		$form_state['rebuild'] = TRUE;
	}
	// Clear the page and block caches.
	$form_state['redirect'] = 'admin/settings/likno_accordions';
	cache_clear_all();
}

/**
* Save changes to a node or add a new node.
*
* @param $node
*   The $node object to be saved. If $node->nid is
*   omitted (or $node->is_new is TRUE), a new node will be added.
*/
function accordion_save($accordion) {
	$transaction = db_transaction();
	try {
		global $user;
		$update_accordion = TRUE;
		// Save the node and node revision.
		if (empty($accordion->id)) {
			// For new nodes, save new records for both the node itself and the node
			// revision.
			drupal_write_record('lwac_table', $accordion);
			$op = 'insert';
		} else {
			drupal_write_record('lwac_table', $accordion, 'id');
			$op = 'update';
		}
		db_ignore_slave();
	} catch (Exception $e) {
		$transaction->rollback();
		throw $e;
	}
}

function likno_accordions_system_hide_notifications(){
	cache_clear_all();
	variable_set('LWAC_Check_Show', FALSE);
	drupal_theme_rebuild();
	return;
}
